@@ -1,3 +1,5 @@
+require 'mime/types'
+
 module AssetSync
   class MultiMime
 
@@ -9,10 +11,10 @@ module AssetSync
         ext_with_dot = ".#{ext}"
         Rack::Mime.mime_type(ext_with_dot)
       else
-        MIME::Types.type_for(ext).first
+        ::MIME::Types.type_for(ext).first
       end
 
     end
 
   end
-end
\ No newline at end of file
+end
